Chunk class

分快上传的块信息

Constructors

Chunk(int number, int offset, int size, bool done)

Properties

done ↔ bool
getter/setter pair
eTag ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
number → int
final
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited